Coverage for C:\src\imod-python\imod\wq\__init__.py: 100%

1"""

2 Create Water Quality model.

3

4 Create an :class:'imod.wq.SeawatModel' and add desired packages to the model

5(e.g. :class:'imod.wq.Well', :class:'imod.wq.Dispersion'). See :doc:'/examples'

6 and :doc:'/model' for workflow documentation.

7"""

8

9# make classes directly available under imod.wq

10 from imod.wq.adv import (

11 AdvectionFiniteDifference,

12 AdvectionHybridMOC,

13 AdvectionMOC,

14 AdvectionModifiedMOC,

15 AdvectionTVD,

16)

17 from imod.wq.bas import BasicFlow

18 from imod.wq.btn import BasicTransport

19 from imod.wq.chd import ConstantHead

20 from imod.wq.dis import TimeDiscretization

21 from imod.wq.drn import Drainage

22 from imod.wq.dsp import Dispersion

23 from imod.wq.evt import (

24 EvapotranspirationHighestActive,

25 EvapotranspirationLayers,

26 EvapotranspirationTopLayer,

27)

28 from imod.wq.ghb import GeneralHeadBoundary

29 from imod.wq.lpf import LayerPropertyFlow

30 from imod.wq.mal import MassLoading

31 from imod.wq.model import SeawatModel

32 from imod.wq.oc import OutputControl

33 from imod.wq.rch import RechargeHighestActive, RechargeLayers, RechargeTopLayer

34 from imod.wq.riv import River

35 from imod.wq.slv import (

36 GeneralizedConjugateGradientSolver,

37 ParallelKrylovFlowSolver,

38 ParallelKrylovTransportSolver,

39 PreconditionedConjugateGradientSolver,

40)

41 from imod.wq.tvc import TimeVaryingConstantConcentration

42 from imod.wq.vdf import VariableDensityFlow

43 from imod.wq.wel import Well